# Generated by Django 3.2.4 on 2021-06-19 08:26

from django.db import migrations, models

import taggit.managers


class Migration(migrations.Migration):
    dependencies = [
        ("tests", "0004_auto_20210619_0826"),
    ]

    operations = [
        migrations.CreateModel(
            name="OrderedModel",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "tags",
                    taggit.managers.TaggableManager(
                        help_text="A comma-separated list of tags.",
                        through="taggit.TaggedItem",
                        to="taggit.Tag",
                        verbose_name="Tags",
                    ),
                ),
            ],
        ),
    ]
